# 2023-05-26 - Polygon zkEVM Root Gauge Factory

Deployment of the `PolygonZkEVMRootGaugeFactory`, for stakeless gauges that bridge funds to their Polygon zkEVM counterparts.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`PolygonZkEVMRootGaugeFactory` artifact](./artifact/PolygonZkEVMRootGaugeFactory.json)
